@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008001;
 
-our $VERSION = '0.59';
+our $VERSION = '0.60';
 
 use Carp qw(croak);
 use URI ();
@@ -227,7 +227,7 @@ sub _get_args {
         if ($line =~ /the uploader has not made this video available in your country/i) {
             croak 'Video not available in your country';
         }
-        elsif ($line =~ /^.+ytplayer\.config\s*=\s*({.*})/) {
+        elsif ($line =~ /^.+ytplayer\.config\s*=\s*(\{.*})/) {
             ($data, undef) = JSON->new->utf8(1)->decode_prefix($1);
             last;
         }
